import * as Result from "../../utility/result.js";
import { OperationError } from "../../operationError.js";
import { BaseDist } from "../BaseDist.js";
import { DistError } from "../DistError.js";
import { PointSetDist } from "../PointSetDist.js";
import { Env } from "../env.js";
export declare class SampleSetDist extends BaseDist {
    samples: readonly number[];
    private constructor();
    static make(a: readonly number[]): Result.result<SampleSetDist, DistError>;
    static fromFn(fn: (i: number) => number, env: Env): Result.result<SampleSetDist, DistError>;
    toString(): string;
    _isEqual(other: SampleSetDist): boolean;
    toSparkline(bucketCount: number, env: Env): Result.result<string, DistError>;
    static fromDist(d: BaseDist, env: Env): Result.result<SampleSetDist, DistError>;
    integralSum(): number;
    normalize(): this;
    min(): number;
    max(): number;
    mean(): number;
    abs(): SampleSetDist;
    truncate(leftCutoff: number | undefined, rightCutoff: number | undefined): Result.result<SampleSetDist, DistError>;
    sample(): number;
    sampleN(n: number): number[];
    cdf(f: number): number;
    inv(f: number): number;
    pdf(f: number, opts: {
        env: Env;
    }): Result.result<number, DistError>;
    variance(): Result.result<number, DistError>;
    mode(): Result.result<number, DistError>;
    range(pWidth: number, absolute?: boolean): Result.result<{
        low: number;
        high: number;
    }, DistError>;
    toPointSetDist(env: Env): Result.result<PointSetDist, DistError>;
    samplesMap(fn: (x: number) => Result.result<number, OperationError>): Result.result<SampleSetDist, DistError>;
}
export declare const map2: ({ fn, t1, t2, }: {
    fn: (v1: number, v2: number) => Result.result<number, OperationError>;
    t1: SampleSetDist;
    t2: SampleSetDist;
}) => Result.result<SampleSetDist, DistError>;
export declare const map3: ({ fn, t1, t2, t3, }: {
    fn: (v1: number, v2: number, v3: number) => Result.result<number, OperationError>;
    t1: SampleSetDist;
    t2: SampleSetDist;
    t3: SampleSetDist;
}) => Result.result<SampleSetDist, DistError>;
export declare const mapN: ({ fn, t1, }: {
    fn: (v: number[]) => Result.result<number, OperationError>;
    t1: SampleSetDist[];
}) => Result.result<SampleSetDist, DistError>;
export declare const mixture: (values: [SampleSetDist, number][], intendedLength: number) => Result.result<SampleSetDist, DistError>;
export type CompareTwoDistsFn = (t1: SampleSetDist, t2: SampleSetDist) => Result.result<SampleSetDist, DistError>;
export type CompareDistWithFloatFn = (t: SampleSetDist, f: number) => Result.result<SampleSetDist, DistError>;
export declare const minOfTwo: CompareTwoDistsFn;
export declare const maxOfTwo: CompareTwoDistsFn;
export declare const minOfFloat: CompareDistWithFloatFn;
export declare const maxOfFloat: CompareDistWithFloatFn;
//# sourceMappingURL=index.d.ts.map