import { ASTNode } from "../ast/parse.js";
import { Value } from "../value/index.js";
export type LambdaExpressionParameter = {
    name: string;
    annotation?: Expression;
};
export type ExpressionContent = {
    type: "Block";
    value: Expression[];
} | {
    type: "Program";
    value: {
        statements: Expression[];
        exports: string[];
    };
} | {
    type: "Array";
    value: Expression[];
} | {
    type: "Dict";
    value: [Expression, Expression][];
} | {
    type: "ResolvedSymbol";
    value: {
        name: string;
        offset: number;
    };
} | {
    type: "Ternary";
    value: {
        condition: Expression;
        ifTrue: Expression;
        ifFalse: Expression;
    };
} | {
    type: "Assign";
    value: {
        left: string;
        right: Expression;
    };
} | {
    type: "Call";
    value: {
        fn: Expression;
        args: Expression[];
    };
} | {
    type: "Lambda";
    value: {
        name?: string;
        parameters: LambdaExpressionParameter[];
        body: Expression;
    };
} | {
    type: "Value";
    value: Value;
};
export type Expression = ExpressionContent & {
    ast: ASTNode;
};
export declare const eArray: (anArray: Expression[]) => ExpressionContent;
export declare const eValue: (value: Value) => ExpressionContent;
export declare const eCall: (fn: Expression, args: Expression[]) => ExpressionContent;
export declare const eLambda: (name: string | undefined, parameters: LambdaExpressionParameter[], body: Expression) => ExpressionContent;
export declare const eDict: (aMap: [Expression, Expression][]) => ExpressionContent;
export declare const eResolvedSymbol: (name: string, offset: number) => ExpressionContent;
export declare const eBlock: (exprs: Expression[]) => ExpressionContent;
export declare const eProgram: (statements: Expression[], exports: string[]) => ExpressionContent;
export declare const eLetStatement: (left: string, right: Expression) => ExpressionContent;
export declare const eTernary: (condition: Expression, ifTrue: Expression, ifFalse: Expression) => ExpressionContent;
export declare const eVoid: () => ExpressionContent;
export declare function expressionToString(expression: Expression): string;
//# sourceMappingURL=index.d.ts.map