import { BaseDist } from "../../dist/BaseDist.js";
import { Lambda } from "../../reducer/lambda.js";
import { ImmutableMap } from "../../utility/immutableMap.js";
import { Scale, Value, Input } from "../../value/index.js";
export type FRType<T> = {
    unpack: (v: Value) => T | undefined;
    pack: (v: T) => Value;
    getName: () => string;
};
export declare const frNumber: FRType<number>;
export declare const frString: FRType<string>;
export declare const frBool: FRType<boolean>;
export declare const frDate: FRType<Date>;
export declare const frTimeDuration: FRType<number>;
export declare const frDistOrNumber: FRType<BaseDist | number>;
export declare const frNumberOrString: FRType<string | number>;
export declare const frDist: FRType<BaseDist>;
export declare const frLambda: FRType<Lambda>;
export declare const frLambdaN: (paramLength: number) => FRType<Lambda>;
export declare const frLambdaNand: (paramLengths: number[]) => FRType<Lambda>;
export declare const frScale: FRType<Scale>;
export declare const frInput: FRType<Input>;
export declare const frArray: <T>(itemType: FRType<T>) => FRType<T[]>;
export declare function frTuple<T1, T2>(type1: FRType<T1>, type2: FRType<T2>): FRType<[T1, T2]>;
export declare function frTuple<T1, T2, T3>(type1: FRType<T1>, type2: FRType<T2>, type3: FRType<T3>): FRType<[T1, T2, T3]>;
export declare function frTuple<T1, T2, T3, T4>(type1: FRType<T1>, type2: FRType<T2>, type3: FRType<T3>, type4: FRType<T4>): FRType<[T1, T2, T3, T4]>;
export declare function frTuple<T1, T2, T3, T4, T5>(type1: FRType<T1>, type2: FRType<T2>, type3: FRType<T3>, type4: FRType<T4>, type5: FRType<T5>): FRType<[T1, T2, T3, T4, T5]>;
export declare const frDictWithArbitraryKeys: <T>(itemType: FRType<T>) => FRType<ImmutableMap<string, T>>;
export declare const frAny: FRType<Value>;
export declare function frDict<K1 extends string, T1>(kv1: [K1, FRType<T1>]): FRType<{
    [k in K1]: T1;
}>;
export declare function frDict<K1 extends string, T1, K2 extends string, T2>(kv1: [K1, FRType<T1>], kv2: [K2, FRType<T2>]): FRType<{
    [k in K1]: T1;
} & {
    [k in K2]: T2;
}>;
export declare function frDict<K1 extends string, T1, K2 extends string, T2, K3 extends string, T3>(kv1: [K1, FRType<T1>], kv2: [K2, FRType<T2>], kv3: [K3, FRType<T3>]): FRType<{
    [k in K1]: T1;
} & {
    [k in K2]: T2;
} & {
    [k in K3]: T3;
}>;
export declare function frDict<K1 extends string, T1, K2 extends string, T2, K3 extends string, T3, K4 extends string, T4>(kv1: [K1, FRType<T1>], kv2: [K2, FRType<T2>], kv3: [K3, FRType<T3>], kv4: [K4, FRType<T4>]): FRType<{
    [k in K1]: T1;
} & {
    [k in K2]: T2;
} & {
    [k in K3]: T3;
} & {
    [k in K4]: T4;
}>;
export declare function frDict<K1 extends string, T1, K2 extends string, T2, K3 extends string, T3, K4 extends string, T4, K5 extends string, T5>(kv1: [K1, FRType<T1>], kv2: [K2, FRType<T2>], kv3: [K3, FRType<T3>], kv4: [K4, FRType<T4>], kv5: [K5, FRType<T5>]): FRType<{
    [k in K1]: T1;
} & {
    [k in K2]: T2;
} & {
    [k in K3]: T3;
} & {
    [k in K4]: T4;
} & {
    [k in K5]: T5;
}>;
export declare function frDict<K1 extends string, T1, K2 extends string, T2, K3 extends string, T3, K4 extends string, T4, K5 extends string, T5, K6 extends string, T6>(kv1: [K1, FRType<T1>], kv2: [K2, FRType<T2>], kv3: [K3, FRType<T3>], kv4: [K4, FRType<T4>], kv5: [K5, FRType<T5>], kv6: [K6, FRType<T6>]): FRType<{
    [k in K1]: T1;
} & {
    [k in K2]: T2;
} & {
    [k in K3]: T3;
} & {
    [k in K4]: T4;
} & {
    [k in K5]: T5;
} & {
    [k in K6]: T6;
}>;
export declare const frOptional: <T>(itemType: FRType<T>) => FRType<T | null> & {
    isOptional: boolean;
};
//# sourceMappingURL=frTypes.d.ts.map