import { BaseDist } from "../../dist/BaseDist.js";
import { DistError } from "../../dist/DistError.js";
import { Env } from "../../dist/env.js";
import { ReducerContext } from "../../reducer/context.js";
import { Lambda } from "../../reducer/lambda.js";
import * as Result from "../../utility/result.js";
import { Value } from "../../value/index.js";
import { FRFunction } from "./core.js";
import { FnDefinition } from "./fnDefinition.js";
import * as SampleSetDist from "../../dist/SampleSetDist/index.js";
import * as SymbolicDist from "../../dist/SymbolicDist.js";
type SimplifiedArgs = Omit<FRFunction, "nameSpace" | "requiresNamespace"> & Partial<Pick<FRFunction, "nameSpace" | "requiresNamespace">>;
type ArgsWithoutDefinitions = Omit<SimplifiedArgs, "definitions">;
export declare class FnFactory {
    nameSpace: string;
    requiresNamespace: boolean;
    constructor(opts: {
        nameSpace: string;
        requiresNamespace: boolean;
    });
    make(args: SimplifiedArgs): FRFunction;
    n2n({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (x: number) => number;
    }): FRFunction;
    nn2n({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (x: number, y: number) => number;
    }): FRFunction;
    nn2b({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (x: number, y: number) => boolean;
    }): FRFunction;
    bb2b({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (x: boolean, y: boolean) => boolean;
    }): FRFunction;
    ss2b({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (x: string, y: string) => boolean;
    }): FRFunction;
    ss2s({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (x: string, y: string) => string;
    }): FRFunction;
    d2s({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (dist: BaseDist, env: Env) => string;
    }): FRFunction;
    dn2s({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (dist: BaseDist, n: number, env: Env) => string;
    }): FRFunction;
    d2n({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (x: BaseDist, env: Env) => number;
    }): FRFunction;
    d2b({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (x: BaseDist, env: Env) => boolean;
    }): FRFunction;
    d2d({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (dist: BaseDist, env: Env) => BaseDist;
    }): FRFunction;
    dn2d({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (dist: BaseDist, n: number, env: Env) => BaseDist;
    }): FRFunction;
    dn2n({ fn, ...args }: ArgsWithoutDefinitions & {
        fn: (dist: BaseDist, n: number, env: Env) => number;
    }): FRFunction;
    fromDefinition(name: string, def: FnDefinition): FRFunction;
}
export declare function unpackDistResult<T>(result: Result.result<T, DistError>): T;
export declare function repackDistResult(result: Result.result<BaseDist, DistError>): Value;
export declare function doNumberLambdaCall(lambda: Lambda, args: Value[], context: ReducerContext): number;
export declare function doBinaryLambdaCall(args: Value[], lambda: Lambda, context: ReducerContext): boolean;
export declare const parseDistFromDistOrNumber: (d: number | BaseDist) => BaseDist;
export declare function distResultToValue(result: Result.result<BaseDist, DistError>): Value;
export declare function distsResultToValue(result: Result.result<BaseDist[], DistError>): Value;
export declare function makeSampleSet(d: BaseDist, env: Env): SampleSetDist.SampleSetDist;
export declare function twoVarSample(v1: BaseDist | number, v2: BaseDist | number, env: Env, fn: (v1: number, v2: number) => Result.result<SymbolicDist.SymbolicDist, string>): Value;
export declare function makeTwoArgsDist(fn: (v1: number, v2: number) => Result.result<SymbolicDist.SymbolicDist, string>): FnDefinition;
export declare function makeOneArgDist(fn: (v: number) => Result.result<SymbolicDist.SymbolicDist, string>): FnDefinition;
export {};
//# sourceMappingURL=helpers.d.ts.map