import { SampleSetDist } from "../../../dist/SampleSetDist/index.js";
import { Env } from "../../../dist/env.js";
import * as Result from "../../../utility/result.js";
import { result } from "../../../utility/result.js";
import { BaseDist } from "../../../dist/BaseDist.js";
import { DistError } from "../../../dist/DistError.js";
import { SymbolicDist } from "../../../dist/SymbolicDist.js";
import { PointSetDist } from "../../../dist/PointSetDist.js";
import { SqDistributionError } from "./SqDistributionError.js";
export declare enum SqDistributionTag {
    PointSet = "PointSet",
    SampleSet = "SampleSet",
    Symbolic = "Symbolic"
}
export declare function wrapDistribution(value: BaseDist): SqDistribution;
export declare abstract class SqAbstractDistribution<T extends BaseDist> {
    _value: T;
    abstract tag: SqDistributionTag;
    constructor(_value: T);
    pointSet(env: Env): Result.result<import("./SqPointSet.js").SqContinuousPointSet | import("./SqPointSet.js").SqDiscretePointSet | import("./SqPointSet.js").SqMixedPointSet, SqDistributionError>;
    asSampleSetDist(env: Env): Result.result<SqSampleSetDistribution, SqDistributionError>;
    toString(): string;
    toSparkline(env: Env): Result.result<string, DistError>;
    mean(env: Env): number;
    integralSum(): number;
    isNormalized(): boolean;
    pdf(env: Env, n: number): Result.result<number, SqDistributionError>;
    cdf(env: Env, n: number): result<number, SqDistributionError>;
    inv(env: Env, n: number): result<number, SqDistributionError>;
    stdev(env: Env): Result.result<number, SqDistributionError>;
}
export declare class SqPointSetDistribution extends SqAbstractDistribution<PointSetDist> {
    tag: SqDistributionTag.PointSet;
}
export declare class SqSampleSetDistribution extends SqAbstractDistribution<SampleSetDist> {
    tag: SqDistributionTag.SampleSet;
    getSamples(): readonly number[];
}
export declare class SqSymbolicDistribution extends SqAbstractDistribution<SymbolicDist> {
    tag: SqDistributionTag.Symbolic;
}
export type SqDistribution = SqPointSetDistribution | SqSampleSetDistribution | SqSymbolicDistribution;
//# sourceMappingURL=index.d.ts.map