import { Env } from "../../dist/env.js";
import * as Result from "../../utility/result.js";
import { Plot } from "../../value/index.js";
import { SqError } from "../SqError.js";
import { SqValueContext } from "../SqValueContext.js";
import { SqDistribution, SqSampleSetDistribution } from "./SqDistribution/index.js";
import { SqLambda } from "./SqLambda.js";
import { SqScale } from "./SqScale.js";
import { SqPlotValue } from "./index.js";
type LabeledSqDistribution = {
    name?: string;
    distribution: SqDistribution;
};
export declare function wrapPlot(value: Plot, context?: SqValueContext): SqPlot;
declare abstract class SqAbstractPlot<T extends Plot["type"]> {
    protected _value: Extract<Plot, {
        type: T;
    }>;
    context?: SqValueContext | undefined;
    abstract tag: T;
    constructor(_value: Extract<Plot, {
        type: T;
    }>, context?: SqValueContext | undefined);
    toString(): string;
    get asValue(): SqPlotValue;
    get title(): string | undefined;
}
export declare class SqDistributionsPlot extends SqAbstractPlot<"distributions"> {
    tag: "distributions";
    static create({ distribution, xScale, yScale, showSummary, title, }: {
        distribution: SqDistribution;
        xScale: SqScale;
        yScale: SqScale;
        showSummary: boolean;
        title?: string;
    }): SqDistributionsPlot;
    get distributions(): LabeledSqDistribution[];
    get showSummary(): boolean;
    get xScale(): SqScale;
    get yScale(): SqScale;
}
export declare class SqNumericFnPlot extends SqAbstractPlot<"numericFn"> {
    tag: "numericFn";
    private createdProgrammatically;
    static create({ fn, xScale, yScale, points, title, }: {
        fn: SqLambda;
        xScale: SqScale;
        yScale: SqScale;
        points?: number;
        title?: string;
    }): SqNumericFnPlot;
    get fn(): SqLambda;
    get xScale(): SqScale;
    get yScale(): SqScale;
    get points(): number | undefined;
    toString(): string;
}
export declare class SqDistFnPlot extends SqAbstractPlot<"distFn"> {
    tag: "distFn";
    private createdProgrammatically;
    static create({ fn, xScale, yScale, distXScale, title, points, }: {
        fn: SqLambda;
        xScale: SqScale;
        yScale: SqScale;
        distXScale: SqScale;
        title?: string;
        points?: number;
    }): SqDistFnPlot;
    get fn(): SqLambda;
    get xScale(): SqScale;
    get yScale(): SqScale;
    get distXScale(): SqScale;
    get points(): number | undefined;
    toString(): string;
}
export declare class SqScatterPlot extends SqAbstractPlot<"scatter"> {
    tag: "scatter";
    private buildSampleSetDist;
    xDist(env: Env): Result.result<SqSampleSetDistribution, SqError>;
    yDist(env: Env): Result.result<SqSampleSetDistribution, SqError>;
    get xScale(): SqScale | undefined;
    get yScale(): SqScale | undefined;
    static zipToPoints(xDist: SqSampleSetDistribution, yDist: SqSampleSetDistribution): {
        x: number;
        y: number;
    }[];
}
export declare class SqRelativeValuesPlot extends SqAbstractPlot<"relativeValues"> {
    tag: "relativeValues";
    get ids(): string[];
    get fn(): SqLambda;
}
export type SqPlot = SqDistributionsPlot | SqNumericFnPlot | SqDistFnPlot | SqScatterPlot | SqRelativeValuesPlot;
export {};
//# sourceMappingURL=SqPlot.d.ts.map