import { result } from "../../utility/result.js";
import { Value } from "../../value/index.js";
import { SqError } from "../SqError.js";
import { SqValueContext } from "../SqValueContext.js";
import { SqArray } from "./SqArray.js";
import { SqCalculator } from "./SqCalculator.js";
import { SqDict } from "./SqDict.js";
import { SqDistribution } from "./SqDistribution/index.js";
import { SqDomain } from "./SqDomain.js";
import { SqInput } from "./SqInput.js";
import { SqLambda } from "./SqLambda.js";
import { SqPlot } from "./SqPlot.js";
import { SqScale } from "./SqScale.js";
import { SqTableChart } from "./SqTableChart.js";
export declare function wrapValue(value: Value, context?: SqValueContext): SqArrayValue | SqBoolValue | SqDateValue | SqDistributionValue | SqLambdaValue | SqNumberValue | SqDictValue | SqStringValue | SqPlotValue | SqTableChartValue | SqCalculatorValue | SqScaleValue | SqTimeDurationValue | SqVoidValue | SqDomainValue | SqInputValue;
export declare abstract class SqAbstractValue<Type extends string, JSType> {
    _value: Extract<Value, {
        type: Type;
    }>;
    context?: SqValueContext | undefined;
    abstract tag: Type;
    constructor(_value: Extract<Value, {
        type: Type;
    }>, context?: SqValueContext | undefined);
    toString(): string;
    publicName(): "String" | "Boolean" | "Void" | "Calculator" | "Date" | "Number" | "Plot" | "Scale" | "Input" | "Domain" | "List" | "Distribution" | "Function" | "Dictionary" | "Time Duration" | "Table Chart";
    abstract asJS(): JSType;
}
export declare class SqArrayValue extends SqAbstractValue<"Array", unknown[]> {
    tag: "Array";
    get value(): SqArray;
    asJS(): unknown[];
}
export declare class SqBoolValue extends SqAbstractValue<"Bool", boolean> {
    tag: "Bool";
    get value(): boolean;
    asJS(): boolean;
}
export declare class SqDateValue extends SqAbstractValue<"Date", Date> {
    tag: "Date";
    get value(): Date;
    asJS(): Date;
}
export declare class SqDistributionValue extends SqAbstractValue<"Dist", SqDistribution> {
    tag: "Dist";
    get value(): SqDistribution;
    asJS(): SqDistribution;
}
export declare class SqLambdaValue extends SqAbstractValue<"Lambda", SqLambda> {
    tag: "Lambda";
    static create(value: SqLambda): SqLambdaValue;
    get value(): SqLambda;
    asJS(): SqLambda;
}
export declare class SqNumberValue extends SqAbstractValue<"Number", number> {
    tag: "Number";
    static create(value: number): SqNumberValue;
    get value(): number;
    asJS(): number;
}
export declare class SqDictValue extends SqAbstractValue<"Dict", Map<string, unknown>> {
    tag: "Dict";
    get value(): SqDict;
    asJS(): Map<string, unknown>;
}
export declare class SqStringValue extends SqAbstractValue<"String", string> {
    tag: "String";
    static create(value: string): SqStringValue;
    get value(): string;
    asJS(): string;
}
export declare class SqTimeDurationValue extends SqAbstractValue<"TimeDuration", number> {
    tag: "TimeDuration";
    get value(): number;
    asJS(): number;
}
export declare class SqPlotValue extends SqAbstractValue<"Plot", SqPlot> {
    tag: "Plot";
    get value(): SqPlot;
    asJS(): SqPlot;
}
export declare class SqTableChartValue extends SqAbstractValue<"TableChart", SqTableChart> {
    tag: "TableChart";
    get value(): SqTableChart;
    asJS(): SqTableChart;
}
export declare class SqCalculatorValue extends SqAbstractValue<"Calculator", SqCalculator> {
    tag: "Calculator";
    get value(): SqCalculator;
    asJS(): SqCalculator;
}
export declare class SqScaleValue extends SqAbstractValue<"Scale", SqScale> {
    tag: "Scale";
    get value(): SqScale;
    asJS(): SqScale;
}
export declare class SqInputValue extends SqAbstractValue<"Input", SqInput> {
    tag: "Input";
    get value(): SqInput;
    asJS(): SqInput;
}
export declare class SqVoidValue extends SqAbstractValue<"Void", null> {
    tag: "Void";
    get value(): null;
    asJS(): null;
}
export declare class SqDomainValue extends SqAbstractValue<"Domain", SqDomain> {
    tag: "Domain";
    get value(): {
        tag: "NumericRange";
        readonly min: number;
        readonly max: number;
        _value: import("../../value/domain.js").NumericRangeDomain;
        toString(): string;
    };
    asJS(): {
        tag: "NumericRange";
        readonly min: number;
        readonly max: number;
        _value: import("../../value/domain.js").NumericRangeDomain;
        toString(): string;
    };
}
export type SqValue = ReturnType<typeof wrapValue>;
export declare function toStringResult(result: result<SqValue, SqError>): string;
//# sourceMappingURL=index.d.ts.map