import { LocationRange } from "peggy";
import { ASTNode } from "../ast/parse.js";
import { Expression } from "../expression/index.js";
import { VDomain, Value } from "../value/index.js";
import { ReducerContext } from "./context.js";
import { Stack } from "./stack.js";
import { FnDefinition } from "../library/registry/fnDefinition.js";
import { FRType } from "../library/registry/frTypes.js";
export type UserDefinedLambdaParameter = {
    name: string;
    domain?: VDomain;
};
type LambdaBody = (args: Value[], context: ReducerContext) => Value;
export declare abstract class BaseLambda {
    body: LambdaBody;
    constructor(body: LambdaBody);
    abstract readonly type: string;
    abstract getName(): string;
    abstract toString(): string;
    abstract parameterString(): string;
    abstract parameterCounts(): number[];
    abstract parameterCountString(): string;
    callFrom(args: Value[], context: ReducerContext, ast: ASTNode | undefined): Value;
    call(args: Value[], context: ReducerContext): Value;
}
export declare class UserDefinedLambda extends BaseLambda {
    parameters: UserDefinedLambdaParameter[];
    location: LocationRange;
    name?: string;
    readonly type = "UserDefinedLambda";
    constructor(name: string | undefined, parameters: UserDefinedLambdaParameter[], stack: Stack, body: Expression, location: LocationRange);
    getName(): string;
    _getParameterNames(): string[];
    parameterString(): string;
    toString(): string;
    parameterCounts(): number[];
    parameterCountString(): string;
}
export declare class BuiltinLambda extends BaseLambda {
    name: string;
    readonly type = "BuiltinLambda";
    _definitions: FnDefinition[];
    constructor(name: string, signatures: FnDefinition[]);
    getName(): string;
    toString(): string;
    parameterString(): string;
    parameterCounts(): number[];
    parameterCountString(): string;
    signatures(): FRType<unknown>[][];
    _call(args: Value[], context: ReducerContext): Value;
}
export type Lambda = UserDefinedLambda | BuiltinLambda;
export {};
//# sourceMappingURL=lambda.d.ts.map