import { distributions, generateInt, generateFloatRange, } from "./generators.js";
import { test, expectEqual } from "./lib.js";
const checkDistributionSame = async (distribution, operation) => {
    await expectEqual(operation(distribution), operation(`PointSet.fromDist(${distribution})`));
    await expectEqual(operation(distribution), operation(`SampleSet.fromDist(${distribution})`));
};
Object.entries(distributions).map(([key, generator]) => {
    const distribution = generator();
    test(`mean is the same for ${key} distribution under all distribution types`, async () => await checkDistributionSame(distribution, (d) => `mean(${d})`));
    test(`cdf is the same for ${key} distribution under all distribution types`, async () => {
        const cdf_value = generateInt();
        await checkDistributionSame(distribution, (d) => `cdf(${d}, ${cdf_value})`);
    });
    test(`pdf is the same for ${key} distribution under all distribution types`, async () => {
        const pdf_value = generateInt();
        await checkDistributionSame(distribution, (d) => `pdf(${d}, ${pdf_value})`);
    });
    test(`inv is the same for ${key} distribution under all distribution types`, async () => {
        const inv_value = generateFloatRange(0, 1);
        await checkDistributionSame(distribution, (d) => `inv(${d}, ${inv_value})`);
    });
});
//# sourceMappingURL=index.js.map